@@ -22,9 +22,9 @@
 
 __author__ = 'Michael S. Russell'
 __email__ = 'michael.r2014@yahoo.co.uk'
-__version__ = '1.0.0'
+__version__ = '1.0.3'
 
-from .anagram import Anagram 
+from .holistic_anagram import Anagram 
 
 anagram = Anagram()
 
